@@ -1,5 +1,6 @@
-from ._colors import get_srgb1, tripcolor
-from ._main import Plotter, plot, plot_colors, plot_contours
+from ._colors import get_srgb1
+from ._main import plot, plot_colors, plot_contour_abs, plot_contour_arg
+from ._tri import tricontour_abs, tripcolor
 from .benchmark import show_kovesi_test_image, show_test_function
 from .create import create_colormap, find_max_srgb_radius, show_circular, show_linear
 
@@ -12,9 +13,10 @@ __all__ = [
     "create_colormap",
     "get_srgb1",
     "plot_colors",
-    "plot_contours",
+    "plot_contour_abs",
+    "plot_contour_arg",
     "plot",
-    "Plotter",
     #
     "tripcolor",
+    "tricontour_abs",
 ]
